mysql> show create procedure calcola_stats\G
*************************** 1. row ***************************
           Procedure: calcola_stats
            sql_mode: 
    Create Procedure: CREATE DEFINER=`myuser`@`localhost` PROCEDURE `calcola_stats`(IN inputdata DATE)

BEGIN
  DECLARE canc INT DEFAULT 0;
  DECLARE indata DATE;


/* if input date is not a valid date calculate stats for the previous day, otherwise calculate stats for the specified date */

  IF inputdata='0000-00-00' THEN
    SET indata=(SELECT CURDATE() - INTERVAL 1 DAY);
    SET canc=1;
  ELSE
    SET indata=inputdata;
  END IF;


/* creation of a temporary support table */
  IF canc=1 THEN
    CREATE TEMPORARY TABLE stats_buff
    SELECT
      IF(referer REGEXP '^http://inter.sina.com.cn','sina',REPLACE(SUBSTRING_INDEX(referer,'.inter.it',1),'http://','')) AS site,
      HOUR(dataora) AS ora,
      COUNT(*) AS page_impressions,
      COUNT(DISTINCT ipaddr) AS unique_ip,
      COUNT(DISTINCT usertrack) AS unique_usertrack
    FROM
      logger
    WHERE
      DATE(dataora)=indata
      AND (referer REGEXP '^http://[a-z0-9]+\.inter\.it' OR referer='-' OR referer REGEXP '^http://inter.sina.com.cn')
    GROUP BY site, ora WITH ROLLUP;
  ELSE
    CREATE TEMPORARY TABLE stats_buff
    SELECT
      IF(referer REGEXP '^http://inter.sina.com.cn','sina',REPLACE(SUBSTRING_INDEX(referer,'.inter.it',1),'http://','')) AS site,
      HOUR(dataora) AS ora,
      COUNT(*) AS page_impressions,
      COUNT(DISTINCT ipaddr) AS unique_ip,
      COUNT(DISTINCT usertrack) AS unique_usertrack
    FROM
      logger_archive
    WHERE
      data=indata
      AND (referer REGEXP '^http://[a-z0-9]+\.inter\.it' OR referer='-' OR referer REGEXP '^http://inter.sina.com.cn')
    GROUP BY site, ora WITH ROLLUP; 
  END IF;


/* insert stats into statistics table */

  DELETE FROM statistics WHERE data=indata;

  INSERT INTO statistics(data,site,page_impressions,unique_ip,unique_usertrack)
    SELECT indata, site, page_impressions, unique_ip, unique_usertrack
    FROM stats_buff
    WHERE ora IS NULL
    AND site IN ('www','interchannel','interclub','intercampus','giovanili','store','archivio','-','interchannel','mobile','sina','reg','interwall','cento','b2b');


/* insert hourly stats */

  DELETE FROM hourly_stats WHERE data=indata;

  INSERT INTO hourly_stats(data,site,ora,page_impressions,unique_ip,unique_usertrack)
    SELECT indata, site, ora, page_impressions, unique_ip, unique_usertrack
    FROM stats_buff
    WHERE ora IS NOT NULL
    AND site IN ('www','interchannel','interclub','intercampus','giovanili','store','archivio','-','interchannel','mobile','sina','reg','interwall','cento','b2b');



/* calculate user session time stats */

  DELETE FROM user_stats WHERE data=indata;

  INSERT INTO user_stats(data,permanenza_media,p0,p10,p20,p30,p40,p50,p60,pmax)
    SELECT indata,
      0,
      SUM(IF(ts_updated='0000-00-00',1,0)) p0,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) < 600 AND ts_updated <> '0000-00-00',1,0)) p10,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) BETWEEN 600 AND 1199,1,0)) p20,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) BETWEEN 1200 AND 1799,1,0)) p30,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) BETWEEN 1800 AND 2399,1,0)) p40,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) BETWEEN 2400 AND 2999,1,0)) p50,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) BETWEEN 3000 AND 3599,1,0)) p60,
      SUM(IF(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) >= 3600,1,0)) pmax
    FROM user_counter
    WHERE DATE(ts_created)=indata;

  UPDATE user_stats
    SET permanenza_media = (SELECT SEC_TO_TIME(AVG(TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created))))
                            FROM user_counter
                            WHERE DATE(ts_created)=indata AND ts_updated<>'0000-00-00 00:00:00' AND TIME_TO_SEC(TIMEDIFF(ts_updated,ts_created)) <= 1800)
    WHERE data=indata;



/* copy previous day data into logger_archive */

  IF canc=1 THEN 

    INSERT INTO logger_archive SELECT dataora, DATE(dataora), ipaddr, referer, browser, retcode, usertrack, language FROM logger WHERE DATE(dataora)=indata;

    DELETE FROM logger WHERE DATE(dataora)=indata;

    DELETE FROM user_counter WHERE DATE(ts_created)=indata;

  END IF;


 DROP TABLE IF EXISTS stats_buff;

END
character_set_client: utf8
collation_connection: utf8_general_ci
  Database Collation: latin1_swedish_ci
1 row in set (0.00 sec)




